@@ -40,7 +40,7 @@ class Timer : public QObject {
     virtual void start(int msec);
     virtual void stop();
 
- signals:
+ Q_SIGNALS:
     void timeout();
 
  private:
