@@ -37,7 +37,7 @@ class LOMIRI_TRANSFERS_PRIVATE DownloadPCW : public PendingCallWatcher {
                                const QDBusPendingCall& call,
                                Download* parent = 0);
 
- private slots:
+ private Q_SLOTS:
     void onFinished(QDBusPendingCallWatcher* watcher);
 };
 
