@@ -41,7 +41,7 @@ public:
     void setType(QString type) { m_type = type; emit typeChanged(); }
     void setMessage(QString message) { m_message = message; emit messageChanged(); }
 
-signals:
+Q_SIGNALS:
     void typeChanged();
     void messageChanged();
 
