@@ -33,7 +33,7 @@ public:
     explicit TestAppArmor(QObject *parent = 0)
         : BaseTestCase("TestAppArmor", parent) { }
 
- private slots:  // NOLINT(whitespace/indent)
+ private Q_SLOTS:  // NOLINT(whitespace/indent)
 
     void init() override;
     void cleanup() override;
